Module bootstrap

Module bootstrap 

Bootstrap sequence orchestration.

This module provides type-safe bootstrap sequencing that enforces initialization dependencies at compile time. The sequence ensures that secrets cannot be initialized without a profile, and paths cannot be initialized without secrets.

Modules

presets

Structs

BootstrapComplete
BootstrapSequence
PathsInitialized
ProfileInitialized
SecretsInitialized
Uninitialized

Traits

BootstrapState