pub struct AnalyticsFactKey {
pub kind: AnalyticsFactKind,
pub source: String,
pub id: AnalyticsFactId,
}Fields
kind: AnalyticsFactKindsource: Stringid: AnalyticsFactIdTrait Implementations
Sourceimpl Clone for AnalyticsFactKey
impl Clone for AnalyticsFactKey
Sourcefn clone(&self) -> AnalyticsFactKey
fn clone(&self) -> AnalyticsFactKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnalyticsFactKey
impl Debug for AnalyticsFactKey
Sourceimpl<'de> Deserialize<'de> for AnalyticsFactKey
impl<'de> Deserialize<'de> for AnalyticsFactKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AnalyticsFactKey
Sourceimpl JsonSchema for AnalyticsFactKey
impl JsonSchema for AnalyticsFactKey
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AnalyticsFactKey
impl PartialEq for AnalyticsFactKey
Sourceimpl Serialize for AnalyticsFactKey
impl Serialize for AnalyticsFactKey
impl StructuralPartialEq for AnalyticsFactKey