pub struct AssessmentConversationKey {
pub source: String,
pub id: AnalyticsFactId,
}Fields
source: Stringid: AnalyticsFactIdTrait Implementations
Sourceimpl Clone for AssessmentConversationKey
impl Clone for AssessmentConversationKey
Sourcefn clone(&self) -> AssessmentConversationKey
fn clone(&self) -> AssessmentConversationKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssessmentConversationKey
impl Debug for AssessmentConversationKey
Sourceimpl<'de> Deserialize<'de> for AssessmentConversationKey
impl<'de> Deserialize<'de> for AssessmentConversationKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AssessmentConversationKey
Sourceimpl JsonSchema for AssessmentConversationKey
impl JsonSchema for AssessmentConversationKey
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for AssessmentConversationKey