pub struct NormalizedArtifactFact {Show 17 fields
pub artifact_key: AnalyticsFactKey,
pub execution_id: String,
pub invocation_key: Option<AnalyticsFactKey>,
pub request_key: Option<AnalyticsFactKey>,
pub occurred_at: DateTime<Utc>,
pub consumer: InvocationConsumerIdentity,
pub skill: Option<InvocationSkillIdentity>,
pub tool_name: String,
pub server_name: Option<String>,
pub artifact_type: String,
pub source: ExecutionSource,
pub correlation: Correlation,
pub is_structured: bool,
pub has_ui_resource: bool,
pub succeeded: bool,
pub payload_bytes: Option<u64>,
pub findings: u64,
}Expand description
One tool result stored as a typed artifact.
It is joined to the invocation and request it belongs to where those are
known. source is the vantage point the platform saw the result from and
correlation says whether it was joined by an exact key or inferred.
Fields
artifact_key: AnalyticsFactKeyexecution_id: Stringinvocation_key: Option<AnalyticsFactKey>request_key: Option<AnalyticsFactKey>occurred_at: DateTime<Utc>consumer: InvocationConsumerIdentityskill: Option<InvocationSkillIdentity>tool_name: Stringserver_name: Option<String>artifact_type: Stringsource: ExecutionSourcecorrelation: Correlationis_structured: boolhas_ui_resource: boolsucceeded: boolpayload_bytes: Option<u64>findings: u64Trait Implementations
Sourceimpl Clone for NormalizedArtifactFact
impl Clone for NormalizedArtifactFact
Sourcefn clone(&self) -> NormalizedArtifactFact
fn clone(&self) -> NormalizedArtifactFact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NormalizedArtifactFact
impl Debug for NormalizedArtifactFact
Sourceimpl<'de> Deserialize<'de> for NormalizedArtifactFact
impl<'de> Deserialize<'de> for NormalizedArtifactFact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NormalizedArtifactFact
Sourceimpl JsonSchema for NormalizedArtifactFact
impl JsonSchema for NormalizedArtifactFact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NormalizedArtifactFact
impl PartialEq for NormalizedArtifactFact
Sourceimpl Serialize for NormalizedArtifactFact
impl Serialize for NormalizedArtifactFact
impl StructuralPartialEq for NormalizedArtifactFact