pub struct NormalizedAssessmentFact {
pub conversation_key: AssessmentConversationKey,
pub assessment_key: AnalyticsFactKey,
pub invocation_key: AnalyticsFactKey,
pub occurred_at: DateTime<Utc>,
pub outcome: AssessmentOutcome,
}Fields
conversation_key: AssessmentConversationKeyassessment_key: AnalyticsFactKeyinvocation_key: AnalyticsFactKeyoccurred_at: DateTime<Utc>outcome: AssessmentOutcomeTrait Implementations
Sourceimpl Clone for NormalizedAssessmentFact
impl Clone for NormalizedAssessmentFact
Sourcefn clone(&self) -> NormalizedAssessmentFact
fn clone(&self) -> NormalizedAssessmentFact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NormalizedAssessmentFact
impl Debug for NormalizedAssessmentFact
Sourceimpl<'de> Deserialize<'de> for NormalizedAssessmentFact
impl<'de> Deserialize<'de> for NormalizedAssessmentFact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NormalizedAssessmentFact
Sourceimpl JsonSchema for NormalizedAssessmentFact
impl JsonSchema for NormalizedAssessmentFact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NormalizedAssessmentFact
impl PartialEq for NormalizedAssessmentFact
Sourceimpl Serialize for NormalizedAssessmentFact
impl Serialize for NormalizedAssessmentFact
impl StructuralPartialEq for NormalizedAssessmentFact