pub struct NormalizedInvocationFact {
pub invocation_id: ResourceInvocationId,
pub occurred_at: DateTime<Utc>,
pub consumer: InvocationConsumerIdentity,
pub attribution: InvocationResourceAttribution,
pub succeeded: bool,
pub latency_micros: Option<u64>,
}Fields
invocation_id: ResourceInvocationIdoccurred_at: DateTime<Utc>consumer: InvocationConsumerIdentityattribution: InvocationResourceAttributionsucceeded: boollatency_micros: Option<u64>Trait Implementations
Sourceimpl Clone for NormalizedInvocationFact
impl Clone for NormalizedInvocationFact
Sourcefn clone(&self) -> NormalizedInvocationFact
fn clone(&self) -> NormalizedInvocationFact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NormalizedInvocationFact
impl Debug for NormalizedInvocationFact
Sourceimpl<'de> Deserialize<'de> for NormalizedInvocationFact
impl<'de> Deserialize<'de> for NormalizedInvocationFact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NormalizedInvocationFact
Sourceimpl JsonSchema for NormalizedInvocationFact
impl JsonSchema for NormalizedInvocationFact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NormalizedInvocationFact
impl PartialEq for NormalizedInvocationFact
Sourceimpl Serialize for NormalizedInvocationFact
impl Serialize for NormalizedInvocationFact
impl StructuralPartialEq for NormalizedInvocationFact