pub struct NormalizedRequestFact {
pub request_key: AnalyticsFactKey,
pub occurred_at: DateTime<Utc>,
pub consumer: InvocationConsumerIdentity,
pub succeeded: bool,
pub spend: RecordedSpend,
pub input_tokens: Option<u64>,
pub output_tokens: Option<u64>,
pub latency_micros: Option<u64>,
}Fields
request_key: AnalyticsFactKeyoccurred_at: DateTime<Utc>consumer: InvocationConsumerIdentitysucceeded: boolspend: RecordedSpendinput_tokens: Option<u64>output_tokens: Option<u64>latency_micros: Option<u64>Trait Implementations
Sourceimpl Clone for NormalizedRequestFact
impl Clone for NormalizedRequestFact
Sourcefn clone(&self) -> NormalizedRequestFact
fn clone(&self) -> NormalizedRequestFact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NormalizedRequestFact
impl Debug for NormalizedRequestFact
Sourceimpl<'de> Deserialize<'de> for NormalizedRequestFact
impl<'de> Deserialize<'de> for NormalizedRequestFact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NormalizedRequestFact
Sourceimpl JsonSchema for NormalizedRequestFact
impl JsonSchema for NormalizedRequestFact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NormalizedRequestFact
impl PartialEq for NormalizedRequestFact
Sourceimpl Serialize for NormalizedRequestFact
impl Serialize for NormalizedRequestFact
impl StructuralPartialEq for NormalizedRequestFact