pub struct NormalizedResourceAssociationFact {
pub association_key: AnalyticsFactKey,
pub invocation_key: AnalyticsFactKey,
pub request_key: AnalyticsFactKey,
pub occurred_at: DateTime<Utc>,
pub attribution: InvocationResourceAttribution,
}Fields
association_key: AnalyticsFactKeyinvocation_key: AnalyticsFactKeyrequest_key: AnalyticsFactKeyoccurred_at: DateTime<Utc>attribution: InvocationResourceAttributionTrait Implementations
Sourceimpl Clone for NormalizedResourceAssociationFact
impl Clone for NormalizedResourceAssociationFact
Sourcefn clone(&self) -> NormalizedResourceAssociationFact
fn clone(&self) -> NormalizedResourceAssociationFact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for NormalizedResourceAssociationFact
impl<'de> Deserialize<'de> for NormalizedResourceAssociationFact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NormalizedResourceAssociationFact
Sourceimpl JsonSchema for NormalizedResourceAssociationFact
impl JsonSchema for NormalizedResourceAssociationFact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for NormalizedResourceAssociationFact