pub struct FileReadback {
pub revision_id: ResourceRevisionId,
pub path: String,
pub digest: ContentDigest,
pub bytes: u64,
pub executable: bool,
pub content_check: ReadbackStatus,
pub mode_check: ReadbackStatus,
}Fields
revision_id: ResourceRevisionIdpath: Stringdigest: ContentDigestbytes: u64executable: boolcontent_check: ReadbackStatusmode_check: ReadbackStatusTrait Implementations
Sourceimpl Clone for FileReadback
impl Clone for FileReadback
Sourcefn clone(&self) -> FileReadback
fn clone(&self) -> FileReadback
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileReadback
impl Debug for FileReadback
Sourceimpl<'de> Deserialize<'de> for FileReadback
impl<'de> Deserialize<'de> for FileReadback
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FileReadback
Sourceimpl JsonSchema for FileReadback
impl JsonSchema for FileReadback
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FileReadback
impl PartialEq for FileReadback
Sourceimpl Serialize for FileReadback
impl Serialize for FileReadback
impl StructuralPartialEq for FileReadback