pub struct InstallationPlanFile {
pub path: String,
pub bytes: Vec<u8>,
pub executable: bool,
}Fields
path: Stringbytes: Vec<u8>executable: boolTrait Implementations
Sourceimpl Clone for InstallationPlanFile
impl Clone for InstallationPlanFile
Sourcefn clone(&self) -> InstallationPlanFile
fn clone(&self) -> InstallationPlanFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstallationPlanFile
impl Debug for InstallationPlanFile
Sourceimpl<'de> Deserialize<'de> for InstallationPlanFile
impl<'de> Deserialize<'de> for InstallationPlanFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InstallationPlanFile
impl JsonSchema for InstallationPlanFile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InstallationPlanFile
impl RefUnwindSafe for InstallationPlanFile
impl Send for InstallationPlanFile
impl Sync for InstallationPlanFile
impl Unpin for InstallationPlanFile
impl UnsafeUnpin for InstallationPlanFile
impl UnwindSafe for InstallationPlanFile