pub struct SessionBindingRequest {
pub receipt_id: InstallationReceiptId,
pub host: EvaluatorClient,
pub session_id: NativeSessionId,
}Fields
receipt_id: InstallationReceiptIdhost: EvaluatorClientsession_id: NativeSessionIdTrait Implementations
Sourceimpl Clone for SessionBindingRequest
impl Clone for SessionBindingRequest
Sourcefn clone(&self) -> SessionBindingRequest
fn clone(&self) -> SessionBindingRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionBindingRequest
impl Debug for SessionBindingRequest
Sourceimpl<'de> Deserialize<'de> for SessionBindingRequest
impl<'de> Deserialize<'de> for SessionBindingRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SessionBindingRequest
Sourceimpl JsonSchema for SessionBindingRequest
impl JsonSchema for SessionBindingRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SessionBindingRequest
impl PartialEq for SessionBindingRequest
Sourceimpl Serialize for SessionBindingRequest
impl Serialize for SessionBindingRequest
impl StructuralPartialEq for SessionBindingRequest