pub struct DependencyVerificationInput {
pub revision_id: ResourceRevisionId,
pub source_id: ManagedSourceId,
pub exact_commit: String,
pub relative_root: String,
pub dependencies: Vec<ResourceRevisionId>,
}Fields
revision_id: ResourceRevisionIdsource_id: ManagedSourceIdexact_commit: Stringrelative_root: Stringdependencies: Vec<ResourceRevisionId>Trait Implementations
Sourceimpl Clone for DependencyVerificationInput
impl Clone for DependencyVerificationInput
Sourcefn clone(&self) -> DependencyVerificationInput
fn clone(&self) -> DependencyVerificationInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DependencyVerificationInput
impl Debug for DependencyVerificationInput
Sourceimpl<'de> Deserialize<'de> for DependencyVerificationInput
impl<'de> Deserialize<'de> for DependencyVerificationInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DependencyVerificationInput
Sourceimpl JsonSchema for DependencyVerificationInput
impl JsonSchema for DependencyVerificationInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DependencyVerificationInput