pub struct DependencyRef {
pub revision_id: ResourceRevisionId,
pub digest: AssetDigest,
}Fields
revision_id: ResourceRevisionIddigest: AssetDigestTrait Implementations
Sourceimpl Clone for DependencyRef
impl Clone for DependencyRef
Sourcefn clone(&self) -> DependencyRef
fn clone(&self) -> DependencyRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DependencyRef
impl Debug for DependencyRef
Sourceimpl<'de> Deserialize<'de> for DependencyRef
impl<'de> Deserialize<'de> for DependencyRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DependencyRef
Sourceimpl JsonSchema for DependencyRef
impl JsonSchema for DependencyRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DependencyRef
impl PartialEq for DependencyRef
Sourceimpl Serialize for DependencyRef
impl Serialize for DependencyRef
impl StructuralPartialEq for DependencyRef