pub struct FileEntry {
pub digest: AssetDigest,
pub bytes: u64,
pub media_type: String,
pub executable: bool,
}Fields
digest: AssetDigestbytes: u64media_type: Stringexecutable: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for FileEntry
impl<'de> Deserialize<'de> for FileEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FileEntry
Sourceimpl JsonSchema for FileEntry
impl JsonSchema for FileEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for FileEntry