pub struct ProtectedResourceMetadata {
pub resource: String,
pub authorization_servers: Vec<String>,
pub scopes_supported: Vec<String>,
pub bearer_methods_supported: Vec<String>,
pub resource_documentation: Option<String>,
pub mcp_extensions_supported: Vec<McpExtensionId>,
}Fields
resource: Stringscopes_supported: Vec<String>bearer_methods_supported: Vec<String>resource_documentation: Option<String>mcp_extensions_supported: Vec<McpExtensionId>MCP extensions the resource requires of a client, by extension id.
Implementations
Sourceimpl ProtectedResourceMetadata
impl ProtectedResourceMetadata
Sourcepub fn requires_enterprise_managed_auth(&self) -> bool
pub fn requires_enterprise_managed_auth(&self) -> bool
Whether the resource requires the Enterprise-Managed Authorization flow — an IdP-issued ID-JAG rather than an interactive authorization redirect the client may have no user present to complete.