pub struct AuthzHookConfig {
pub mode: AuthzMode,
pub url: Option<String>,
pub timeout_ms: u64,
pub acknowledgement: Option<String>,
}Fields
mode: AuthzModeurl: Option<String>timeout_ms: u64acknowledgement: Option<String>Trait Implementations
Sourceimpl Clone for AuthzHookConfig
impl Clone for AuthzHookConfig
Sourcefn clone(&self) -> AuthzHookConfig
fn clone(&self) -> AuthzHookConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthzHookConfig
impl Debug for AuthzHookConfig
Sourceimpl<'de> Deserialize<'de> for AuthzHookConfig
impl<'de> Deserialize<'de> for AuthzHookConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuthzHookConfig
impl JsonSchema for AuthzHookConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AuthzHookConfig
impl RefUnwindSafe for AuthzHookConfig
impl Send for AuthzHookConfig
impl Sync for AuthzHookConfig
impl Unpin for AuthzHookConfig
impl UnsafeUnpin for AuthzHookConfig
impl UnwindSafe for AuthzHookConfig