pub struct EvaluatorConfig {
pub worker_id: EvalWorkerId,
pub client_image: String,
pub relay_image: String,
pub control_network: String,
pub docker: PathBuf,
pub workspace_root: PathBuf,
}Expand description
Present only on replicas that run evaluator assignments; the supervisor job is idle without it.
Fields
worker_id: EvalWorkerIdclient_image: Stringrelay_image: Stringcontrol_network: Stringdocker: PathBufworkspace_root: PathBufTrait Implementations
Sourceimpl Clone for EvaluatorConfig
impl Clone for EvaluatorConfig
Sourcefn clone(&self) -> EvaluatorConfig
fn clone(&self) -> EvaluatorConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvaluatorConfig
impl Debug for EvaluatorConfig
Sourceimpl<'de> Deserialize<'de> for EvaluatorConfig
impl<'de> Deserialize<'de> for EvaluatorConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvaluatorConfig
impl JsonSchema for EvaluatorConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvaluatorConfig
impl RefUnwindSafe for EvaluatorConfig
impl Send for EvaluatorConfig
impl Sync for EvaluatorConfig
impl Unpin for EvaluatorConfig
impl UnsafeUnpin for EvaluatorConfig
impl UnwindSafe for EvaluatorConfig