pub struct GatewayModel {
pub id: ModelId,
pub provider: ProviderId,
pub aliases: Vec<ModelId>,
pub display_name: Option<String>,
pub upstream_model: Option<String>,
pub pricing: Option<ModelPricing>,
}Fields
id: ModelIdprovider: ProviderIdaliases: Vec<ModelId>display_name: Option<String>upstream_model: Option<String>pricing: Option<ModelPricing>Trait Implementations
Sourceimpl Clone for GatewayModel
impl Clone for GatewayModel
Sourcefn clone(&self) -> GatewayModel
fn clone(&self) -> GatewayModel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GatewayModel
impl Debug for GatewayModel
Sourceimpl<'de> Deserialize<'de> for GatewayModel
impl<'de> Deserialize<'de> for GatewayModel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GatewayModel
impl JsonSchema for GatewayModel
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GatewayModel
impl RefUnwindSafe for GatewayModel
impl Send for GatewayModel
impl Sync for GatewayModel
impl Unpin for GatewayModel
impl UnsafeUnpin for GatewayModel
impl UnwindSafe for GatewayModel