pub struct GatewayProvider {
pub name: ProviderId,
pub endpoint: String,
pub api_key_secret: SecretName,
pub extra_headers: HashMap<String, String>,
}Fields
name: ProviderIdendpoint: Stringapi_key_secret: SecretNameextra_headers: HashMap<String, String>Trait Implementations
Sourceimpl Clone for GatewayProvider
impl Clone for GatewayProvider
Sourcefn clone(&self) -> GatewayProvider
fn clone(&self) -> GatewayProvider
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GatewayProvider
impl Debug for GatewayProvider
Sourceimpl<'de> Deserialize<'de> for GatewayProvider
impl<'de> Deserialize<'de> for GatewayProvider
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GatewayProvider
impl JsonSchema for GatewayProvider
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GatewayProvider
impl RefUnwindSafe for GatewayProvider
impl Send for GatewayProvider
impl Sync for GatewayProvider
impl Unpin for GatewayProvider
impl UnsafeUnpin for GatewayProvider
impl UnwindSafe for GatewayProvider