pub struct HttpsServicesSource {
pub url: String,
pub auth_secret: Option<String>,
pub verify: BundleVerification,
}Fields
url: Stringauth_secret: Option<String>verify: BundleVerificationTrait Implementations
Sourceimpl Clone for HttpsServicesSource
impl Clone for HttpsServicesSource
Sourcefn clone(&self) -> HttpsServicesSource
fn clone(&self) -> HttpsServicesSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HttpsServicesSource
impl Debug for HttpsServicesSource
Sourceimpl<'de> Deserialize<'de> for HttpsServicesSource
impl<'de> Deserialize<'de> for HttpsServicesSource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HttpsServicesSource
Sourceimpl JsonSchema for HttpsServicesSource
impl JsonSchema for HttpsServicesSource
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HttpsServicesSource
impl PartialEq for HttpsServicesSource
Sourceimpl Serialize for HttpsServicesSource
impl Serialize for HttpsServicesSource
impl StructuralPartialEq for HttpsServicesSource