pub struct JudgeProfile {
pub automatic: bool,
}Fields
automatic: boolTrait Implementations
Sourceimpl Clone for JudgeProfile
impl Clone for JudgeProfile
impl Copy for JudgeProfile
Sourceimpl Debug for JudgeProfile
impl Debug for JudgeProfile
Sourceimpl Default for JudgeProfile
impl Default for JudgeProfile
Sourceimpl<'de> Deserialize<'de> for JudgeProfile
impl<'de> Deserialize<'de> for JudgeProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for JudgeProfile
Sourceimpl JsonSchema for JudgeProfile
impl JsonSchema for JudgeProfile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for JudgeProfile
impl PartialEq for JudgeProfile
Sourceimpl Serialize for JudgeProfile
impl Serialize for JudgeProfile
impl StructuralPartialEq for JudgeProfile