pub struct OciServicesSource {
pub reference: String,
pub auth_secret: Option<String>,
pub verify: BundleVerification,
}Fields
reference: Stringauth_secret: Option<String>verify: BundleVerificationTrait Implementations
Sourceimpl Clone for OciServicesSource
impl Clone for OciServicesSource
Sourcefn clone(&self) -> OciServicesSource
fn clone(&self) -> OciServicesSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OciServicesSource
impl Debug for OciServicesSource
Sourceimpl<'de> Deserialize<'de> for OciServicesSource
impl<'de> Deserialize<'de> for OciServicesSource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OciServicesSource
Sourceimpl JsonSchema for OciServicesSource
impl JsonSchema for OciServicesSource
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OciServicesSource
impl PartialEq for OciServicesSource
Sourceimpl Serialize for OciServicesSource
impl Serialize for OciServicesSource
impl StructuralPartialEq for OciServicesSource