pub struct RuntimeConfig {
pub environment: Environment,
pub log_level: LogLevel,
pub output_format: OutputFormat,
pub no_color: bool,
pub non_interactive: bool,
}Fields
environment: Environmentlog_level: LogLeveloutput_format: OutputFormatno_color: boolnon_interactive: boolTrait Implementations
Sourceimpl Clone for RuntimeConfig
impl Clone for RuntimeConfig
Sourcefn clone(&self) -> RuntimeConfig
fn clone(&self) -> RuntimeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeConfig
impl Debug for RuntimeConfig
Sourceimpl Default for RuntimeConfig
impl Default for RuntimeConfig
Sourceimpl<'de> Deserialize<'de> for RuntimeConfig
impl<'de> Deserialize<'de> for RuntimeConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RuntimeConfig
impl JsonSchema for RuntimeConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for RuntimeConfig
impl Serialize for RuntimeConfig
impl Copy for RuntimeConfig