pub struct SecretsConfig {
pub secrets_path: String,
pub validation: SecretsValidationMode,
pub source: SecretsSource,
}Fields
secrets_path: Stringvalidation: SecretsValidationModesource: SecretsSourceTrait Implementations
Sourceimpl Clone for SecretsConfig
impl Clone for SecretsConfig
Sourcefn clone(&self) -> SecretsConfig
fn clone(&self) -> SecretsConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecretsConfig
impl Debug for SecretsConfig
Sourceimpl<'de> Deserialize<'de> for SecretsConfig
impl<'de> Deserialize<'de> for SecretsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SecretsConfig
impl JsonSchema for SecretsConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SecretsConfig
impl RefUnwindSafe for SecretsConfig
impl Send for SecretsConfig
impl Sync for SecretsConfig
impl Unpin for SecretsConfig
impl UnsafeUnpin for SecretsConfig
impl UnwindSafe for SecretsConfig