pub struct TierMultipliers {
pub admin: f64,
pub user: f64,
pub a2a: f64,
pub mcp: f64,
pub service: f64,
pub anon: f64,
}Fields
admin: f64user: f64a2a: f64mcp: f64service: f64anon: f64Trait Implementations
Sourceimpl Clone for TierMultipliers
impl Clone for TierMultipliers
Sourcefn clone(&self) -> TierMultipliers
fn clone(&self) -> TierMultipliers
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TierMultipliers
Sourceimpl Debug for TierMultipliers
impl Debug for TierMultipliers
Sourceimpl Default for TierMultipliers
impl Default for TierMultipliers
Sourceimpl<'de> Deserialize<'de> for TierMultipliers
impl<'de> Deserialize<'de> for TierMultipliers
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TierMultipliers
impl JsonSchema for TierMultipliers
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TierMultipliers
impl RefUnwindSafe for TierMultipliers
impl Send for TierMultipliers
impl Sync for TierMultipliers
impl Unpin for TierMultipliers
impl UnsafeUnpin for TierMultipliers
impl UnwindSafe for TierMultipliers