pub struct VaultSecretsConfig {
pub address: String,
pub mount: String,
pub path: String,
pub namespace: Option<String>,
pub auth: VaultAuth,
pub keys: BTreeMap<String, VaultKeyRef>,
pub ca_cert_path: Option<String>,
pub timeout_secs: u64,
pub retries: u8,
}Fields
address: Stringmount: Stringpath: Stringnamespace: Option<String>auth: VaultAuthkeys: BTreeMap<String, VaultKeyRef>ca_cert_path: Option<String>timeout_secs: u64retries: u8Trait Implementations
Sourceimpl Clone for VaultSecretsConfig
impl Clone for VaultSecretsConfig
Sourcefn clone(&self) -> VaultSecretsConfig
fn clone(&self) -> VaultSecretsConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VaultSecretsConfig
impl Debug for VaultSecretsConfig
Sourceimpl<'de> Deserialize<'de> for VaultSecretsConfig
impl<'de> Deserialize<'de> for VaultSecretsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VaultSecretsConfig
Sourceimpl JsonSchema for VaultSecretsConfig
impl JsonSchema for VaultSecretsConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VaultSecretsConfig
impl PartialEq for VaultSecretsConfig
Sourceimpl Serialize for VaultSecretsConfig
impl Serialize for VaultSecretsConfig
impl StructuralPartialEq for VaultSecretsConfig