pub struct PluginSummary {
pub id: PluginId,
pub name: String,
pub display_name: String,
pub enabled: bool,
pub skill_count: usize,
pub agent_count: usize,
}Fields
id: PluginIdname: Stringdisplay_name: Stringenabled: boolskill_count: usizeagent_count: usizeTrait Implementations
Sourceimpl Clone for PluginSummary
impl Clone for PluginSummary
Sourcefn clone(&self) -> PluginSummary
fn clone(&self) -> PluginSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PluginSummary
impl Debug for PluginSummary
Sourceimpl<'de> Deserialize<'de> for PluginSummary
impl<'de> Deserialize<'de> for PluginSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&PluginConfig> for PluginSummary
impl From<&PluginConfig> for PluginSummary
Sourcefn from(config: &PluginConfig) -> Self
fn from(config: &PluginConfig) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for PluginSummary
impl JsonSchema for PluginSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PluginSummary
impl RefUnwindSafe for PluginSummary
impl Send for PluginSummary
impl Sync for PluginSummary
impl Unpin for PluginSummary
impl UnsafeUnpin for PluginSummary
impl UnwindSafe for PluginSummary