pub struct PluginVariableDef {
pub name: String,
pub description: String,
pub required: bool,
pub secret: bool,
pub example: Option<String>,
}Fields
name: Stringdescription: Stringrequired: boolsecret: boolexample: Option<String>Trait Implementations
Sourceimpl Clone for PluginVariableDef
impl Clone for PluginVariableDef
Sourcefn clone(&self) -> PluginVariableDef
fn clone(&self) -> PluginVariableDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PluginVariableDef
impl Debug for PluginVariableDef
Sourceimpl<'de> Deserialize<'de> for PluginVariableDef
impl<'de> Deserialize<'de> for PluginVariableDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PluginVariableDef
impl JsonSchema for PluginVariableDef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PluginVariableDef
impl RefUnwindSafe for PluginVariableDef
impl Send for PluginVariableDef
impl Sync for PluginVariableDef
impl Unpin for PluginVariableDef
impl UnsafeUnpin for PluginVariableDef
impl UnwindSafe for PluginVariableDef