pub struct SlackAuthzConfig {
pub allowed_roles: Vec<String>,
}Expand description
Authorization seed for an app — the roles granted access to its surfaces.
Fields
allowed_roles: Vec<String>Trait Implementations
Sourceimpl Clone for SlackAuthzConfig
impl Clone for SlackAuthzConfig
Sourcefn clone(&self) -> SlackAuthzConfig
fn clone(&self) -> SlackAuthzConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SlackAuthzConfig
impl Debug for SlackAuthzConfig
Sourceimpl Default for SlackAuthzConfig
impl Default for SlackAuthzConfig
Sourcefn default() -> SlackAuthzConfig
fn default() -> SlackAuthzConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SlackAuthzConfig
impl<'de> Deserialize<'de> for SlackAuthzConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SlackAuthzConfig
impl JsonSchema for SlackAuthzConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SlackAuthzConfig
impl RefUnwindSafe for SlackAuthzConfig
impl Send for SlackAuthzConfig
impl Sync for SlackAuthzConfig
impl Unpin for SlackAuthzConfig
impl UnsafeUnpin for SlackAuthzConfig
impl UnwindSafe for SlackAuthzConfig