artifacts module — see crate-level docs for context.
Copyright (c) systemprompt.io — Business Source License 1.1. See https://systemprompt.io for licensing details.
Re-exports
pub use card::CardCta;pub use card::CardSection;pub use card::PresentationCardArtifact;pub use card::PresentationCardResponse;pub use chart::ChartArtifact;pub use chart::ChartDataset;pub use cli::CliArtifact;pub use copy_paste_text::CopyPasteTextArtifact;pub use dashboard::ChartSectionData;pub use dashboard::DashboardArtifact;pub use dashboard::DashboardHints;pub use dashboard::DashboardSection;pub use dashboard::DatabaseStatus;pub use dashboard::ErrorCounts;pub use dashboard::ItemList;pub use dashboard::LayoutMode;pub use dashboard::LayoutWidth;pub use dashboard::ListItem as DashboardListItem;pub use dashboard::ListSectionData;pub use dashboard::MetricCard;pub use dashboard::MetricStatus;pub use dashboard::MetricsCardsData;pub use dashboard::SectionLayout;pub use dashboard::SectionType;pub use dashboard::ServiceStatus;pub use dashboard::SortConfig;pub use dashboard::StatusSectionData;pub use dashboard::TableSectionData;pub use list::ListArtifact;pub use list::ListItem;pub use message::MessageArtifact;pub use message::NoticeLine;pub use metadata::EXECUTION_META_KEY;pub use metadata::ExecutionMetadata;pub use metadata::ToolResponse;pub use research::ResearchArtifact;pub use research::SourceCitation;pub use table::Column;pub use table::TableArtifact;pub use table::TableHints;pub use table::TableResponse;pub use text::TextArtifact;pub use traits::Artifact;pub use traits::ArtifactSchema;pub use types::Alignment;pub use types::ArtifactType;pub use types::AxisType;pub use types::ChartType;pub use types::ColumnType;pub use types::SortOrder;pub use audio::AudioArtifact;pub use image::ImageArtifact;pub use video::VideoArtifact;
Modules
- audio
- Audio playback artifact.
- card
- Presentation-card artifact.
- chart
- Chart artifact.
- cli
- CLI artifact envelope.
- copy_
paste_ text - Copy-to-clipboard text artifact.
- dashboard
- Dashboard artifact and its composable sections.
- image
- Image artifact.
- list
- List artifact.
- message
- Message/notice artifact: levelled notice lines a command emits as structured output so machine consumers never receive an empty response.
- metadata
- Execution provenance carried on every artifact.
- research
- Research artifact shape with source citations.
- table
- Tabular artifact: columnar data records returned by skills and tools.
- text
- Text artifact: a titled block of free-form text returned by skills and tools.
- traits
- Traits artifacts implement to expose their type, schema, and JSON form.
- types
ArtifactTypeenum for typed MCP artifacts.- video
- Video artifact: a playable video reference with playback options.