pub struct AuthzConfig {
pub hook: AuthzHookConfig,
}Fields
hook: AuthzHookConfigTrait Implementations
Sourceimpl Clone for AuthzConfig
impl Clone for AuthzConfig
Sourcefn clone(&self) -> AuthzConfig
fn clone(&self) -> AuthzConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthzConfig
impl Debug for AuthzConfig
Sourceimpl<'de> Deserialize<'de> for AuthzConfig
impl<'de> Deserialize<'de> for AuthzConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuthzConfig
impl JsonSchema for AuthzConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AuthzConfig
impl RefUnwindSafe for AuthzConfig
impl Send for AuthzConfig
impl Sync for AuthzConfig
impl Unpin for AuthzConfig
impl UnsafeUnpin for AuthzConfig
impl UnwindSafe for AuthzConfig