pub struct ContentNegotiationConfig {
pub enabled: bool,
pub markdown_suffix: String,
}Fields
enabled: boolmarkdown_suffix: StringTrait Implementations
Sourceimpl Clone for ContentNegotiationConfig
impl Clone for ContentNegotiationConfig
Sourcefn clone(&self) -> ContentNegotiationConfig
fn clone(&self) -> ContentNegotiationConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentNegotiationConfig
impl Debug for ContentNegotiationConfig
Sourceimpl Default for ContentNegotiationConfig
impl Default for ContentNegotiationConfig
Sourceimpl<'de> Deserialize<'de> for ContentNegotiationConfig
impl<'de> Deserialize<'de> for ContentNegotiationConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContentNegotiationConfig
impl JsonSchema for ContentNegotiationConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ContentNegotiationConfig
impl RefUnwindSafe for ContentNegotiationConfig
impl Send for ContentNegotiationConfig
impl Sync for ContentNegotiationConfig
impl Unpin for ContentNegotiationConfig
impl UnsafeUnpin for ContentNegotiationConfig
impl UnwindSafe for ContentNegotiationConfig